package com.dgtly.apiframework.util;

import com.alibaba.fastjson.JSONObject;
import com.dgtly.common.exception.api.QyWeixinException;
import com.dgtly.common.utils.RedisUtil;
import com.dgtly.common.utils.http.HttpUtils;
import com.dgtly.wxportal.domain.WxQyUser;
import com.dgtly.wxportal.service.IWxQyUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;


/**
 * 企业微信工具类
 */
@Component
public class QyWeixinUtil {

    @Autowired
    private RedisUtil redisUtil;

    @Autowired
    private IWxQyUserService wxQyUserService;

    private String redis_qywxtoken_key="QYWX_ACCESS_TOKEN";

    //获取access_token的接口地址（GET） 限200（次/天）
    private String access_token_url = "https://qyapi.weixin.qq.com/cgi-bin/gettoken?corpid=%s&corpsecret=%s";

    //获取用户信息url
    private String getuserinfo_url = "https://qyapi.weixin.qq.com/cgi-bin/user/getuserinfo?access_token=%s&code=%s";

    //网页授权链接
    private String oauth2_url = "https://open.weixin.qq.com/connect/oauth2/authorize?appid=%s&redirect_uri=%s&response_type=code&scope=snsapi_base&state=%s#wechat_redirect";


    //获取用户详细信息
    private String getUser_url = "https://qyapi.weixin.qq.com/cgi-bin/user/get?access_token=%s&userid=%s";


    @Value(value = "${qiyeweixin.corpid}")
    private String corpid;



    @Value(value = "${qiyeweixin.corpsecret}")
    private String corpsecret;

    /**
     * 获取access_token
     * @return
     */
    public String getAccessToken() {
        if(redisUtil.hasKey(redis_qywxtoken_key)){
            return redisUtil.get(redis_qywxtoken_key).toString();
        }
        String url = String.format(access_token_url,corpid,corpsecret );
        JSONObject json = JSONObject.parseObject(HttpUtils.sendGet(url));
        Integer errcode = json.getInteger("errcode");
        if(errcode!=0){
            throw new QyWeixinException(errcode,json.getString("errmsg"),url);
        }
        String token = json.getString("access_token");
        redisUtil.set(redis_qywxtoken_key,token,json.getLong("expires_in"));

        return token;
    }

    /**
     * 获取企业微信用户的userId
     * @return
     */
    public JSONObject getUserId(String code) {
        String url = String.format(getuserinfo_url,getAccessToken(),code );

        JSONObject json  = JSONObject.parseObject(HttpUtils.sendGet(url));
        Integer errcode = json.getInteger("errcode");
        if(errcode!=0){
            throw new QyWeixinException(errcode,json.getString("errmsg"),url);
        }
        /*
        * 当用户为企业成员时返回示例如下：
        * {
        *   "errcode": 0,
        *   "errmsg": "ok",
        *   "UserId":"USERID",
        *   "DeviceId":"DEVICEID"
        *   }
        *
        * 非企业成员授权时返回示例如下：
        * {
        *   "errcode": 0,
        *   "errmsg": "ok",
        *   "OpenId":"OPENID",
        *   "DeviceId":"DEVICEID"
        *   }
        *
        * */

        return json;
    }

    public String getOauth2Url(String redirect,String state){
        return String.format(oauth2_url,corpid,redirect,state);
    }

    public WxQyUser gerUserDetail(String userId){
        String url =  String.format(getUser_url,getAccessToken(),userId);

        String result = HttpUtils.sendGet(url);

        JSONObject json = JSONObject.parseObject(result);

        Integer errcode = json.getInteger("errcode");
        if(errcode!=0){
            throw new QyWeixinException(errcode,json.getString("errmsg"),url);
        }
        WxQyUser wxQyUser = JSONObject.parseObject(result,WxQyUser.class);
        wxQyUser.setJson(result);
        return wxQyUser;

    }

}
