package com.dgtly.order.controller;

import java.util.List;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.dgtly.common.utils.MapDataUtil;
import com.dgtly.order.domain.OrderBase;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.MediaType;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.util.MultiValueMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.dgtly.common.core.controller.BaseController;
import org.springframework.web.client.RestTemplate;

import javax.servlet.http.HttpServletRequest;

/**
 * 订单基础 订单的基础信息Controller
 * 
 * @author qxp
 * @date 2020-07-10
 */
@Controller
@RequestMapping("/order/orderbase")
public class OrderBaseController extends BaseController {
    private String prefix = "order/orderbase";

    @Autowired
    private RestTemplate restTemplate;

    @Value(value = "${ruoyi.cloudPath}")
    private String cloudPath;


    @RequiresPermissions("order:orderbase:view")
    @GetMapping()
    public String orderbase() {
        return prefix + "/orderbase";
    }

    /**
     * 查询订单基础 订单的基础信息列表
     */
    @RequiresPermissions("order:orderbase:list")
    @PostMapping("/list")
    @ResponseBody
    public Object list(HttpServletRequest request) {
        //设置为form方式
        HttpHeaders headers = new HttpHeaders();
        headers.setContentType(MediaType.APPLICATION_FORM_URLENCODED);
        MultiValueMap<String, Object> map = MapDataUtil.convertMultiValueMap(request);
            HttpEntity<Object> requestEntity
                = new HttpEntity<>(map, headers);
        String str = restTemplate.postForObject(cloudPath + request.getRequestURI(), requestEntity, String.class);
        return str;
    }


    /**
     * 修改订单基础 订单的基础信息
     */
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") Long id, ModelMap mmap) {
        String str = restTemplate.getForObject(cloudPath + "/order/orderbase/info/" + id, String.class);
        OrderBase orderBase = JSONObject.toJavaObject(JSON.parseObject(str), OrderBase.class);
        mmap.put("orderBase", orderBase);
        return prefix + "/edit";
    }
}


